Package: BBmisc
Title: Miscellaneous Helper Functions for B. Bischl
Version: 1.13
Authors@R: c(
    person("Bernd", "Bischl", , "bernd_bischl@gmx.net", role = c("aut", "cre")),
    person("Michel", "Lang", , "michellang@gmail.com", role = "aut"),
    person("Jakob", "Bossek", , "j.bossek@gmail.com", role = "aut"),
    person("Daniel", "Horn", , "daniel.horn@tu-dortmund.de", role = "aut"),
    person("Jakob", "Richter", , "code@jakob-r.de", role = "aut"),
    person("Dirk", "Surmann", , "surmann@statistik.tu-dortmund.de", role = "aut")
  )
Description: Miscellaneous helper functions for and from B. Bischl and
    some other guys, mainly for package development.
License: BSD_2_clause + file LICENSE
URL: https://github.com/berndbischl/BBmisc
BugReports: https://github.com/berndbischl/BBmisc/issues
Imports: checkmate (>= 1.8.0), data.table, methods, stats, utils
Suggests: codetools, microbenchmark, testthat
ByteCompile: yes
Encoding: UTF-8
RoxygenNote: 7.2.1
NeedsCompilation: yes
Packaged: 2022-09-29 09:08:21 UTC; michel
Author: Bernd Bischl [aut, cre],
  Michel Lang [aut],
  Jakob Bossek [aut],
  Daniel Horn [aut],
  Jakob Richter [aut],
  Dirk Surmann [aut]
Maintainer: Bernd Bischl <bernd_bischl@gmx.net>
Repository: CRAN
Date/Publication: 2022-09-29 10:30:08 UTC
Built: R 4.2.0; aarch64-apple-darwin20; 2023-04-01 17:13:23 UTC; unix
Archs: BBmisc.so.dSYM
