Package: BBmisc
Title: Miscellaneous Helper Functions for B. Bischl
Version: 1.13.1
Authors@R: c(
    person("Bernd", "Bischl", , "bernd_bischl@gmx.net", role = c("aut", "cre")),
    person("Michel", "Lang", , "michellang@gmail.com", role = "aut"),
    person("Jakob", "Bossek", , "j.bossek@gmail.com", role = "aut"),
    person("Daniel", "Horn", , "daniel.horn@tu-dortmund.de", role = "aut"),
    person("Jakob", "Richter", , "code@jakob-r.de", role = "aut"),
    person("Dirk", "Surmann", , "surmann@statistik.tu-dortmund.de", role = "aut")
  )
Description: Miscellaneous helper functions for and from B. Bischl and
    some other guys, mainly for package development.
License: BSD_2_clause + file LICENSE
URL: https://github.com/berndbischl/BBmisc
BugReports: https://github.com/berndbischl/BBmisc/issues
Imports: checkmate (>= 1.8.0), data.table, methods, stats, utils
Suggests: codetools, microbenchmark, testthat
ByteCompile: yes
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: yes
Packaged: 2026-01-21 10:42:03 UTC; marc
Author: Bernd Bischl [aut, cre],
  Michel Lang [aut],
  Jakob Bossek [aut],
  Daniel Horn [aut],
  Jakob Richter [aut],
  Dirk Surmann [aut]
Maintainer: Bernd Bischl <bernd_bischl@gmx.net>
Repository: CRAN
Date/Publication: 2026-01-21 11:20:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 16:35:39 UTC; unix
Archs: BBmisc.so.dSYM
