# Generated by roxygen2: do not edit by hand

S3method(normalize,data.frame)
S3method(normalize,matrix)
S3method(normalize,numeric)
export("%btwn%")
export("%nin%")
export(addClasses)
export(argsAsNamedList)
export(asMatrixCols)
export(asMatrixRows)
export(asQuoted)
export(binPack)
export(cFactor)
export(capitalizeStrings)
export(catf)
export(checkArg)
export(checkListElementClass)
export(chunk)
export(clipString)
export(coalesce)
export(collapse)
export(collapsef)
export(computeMode)
export(convertColsToList)
export(convertDataFrameCols)
export(convertDfCols)
export(convertInteger)
export(convertIntegers)
export(convertListOfRowsToDataFrame)
export(convertMatrixType)
export(convertRowsToList)
export(convertToShortString)
export(dapply)
export(do.call2)
export(dropNamed)
export(ensureVector)
export(explode)
export(extractSubList)
export(filterNull)
export(getAttributeNames)
export(getBestIndex)
export(getClass1)
export(getFirst)
export(getLast)
export(getMaxIndex)
export(getMaxIndexOfCols)
export(getMaxIndexOfRows)
export(getMinIndex)
export(getMinIndexOfCols)
export(getMinIndexOfRows)
export(getOperatingSystem)
export(getRelativePath)
export(getUnixTime)
export(getUsedFactorLevels)
export(hasAttributes)
export(insert)
export(is.error)
export(isDarwin)
export(isDirectory)
export(isEmptyDirectory)
export(isExpensiveExampleOk)
export(isFALSE)
export(isLinux)
export(isProperlyNamed)
export(isScalarCharacter)
export(isScalarComplex)
export(isScalarFactor)
export(isScalarInteger)
export(isScalarLogical)
export(isScalarNA)
export(isScalarNumeric)
export(isScalarValue)
export(isSubset)
export(isSuperset)
export(isUnix)
export(isValidName)
export(isWindows)
export(itostr)
export(lib)
export(listToShortString)
export(load2)
export(lsort)
export(makeDataFrame)
export(makeFileCache)
export(makeProgressBar)
export(makeS3Obj)
export(makeSimpleFileLogger)
export(mapValues)
export(messagef)
export(namedList)
export(names2)
export(normalize)
export(optimizeSubInts)
export(pause)
export(printHead)
export(printStrToChar)
export(printToChar)
export(rangeVal)
export(requirePackages)
export(rowLapply)
export(rowSapply)
export(save2)
export(seq_col)
export(seq_row)
export(setAttribute)
export(setClasses)
export(setColNames)
export(setRowNames)
export(setValue)
export(sortByCol)
export(splitPath)
export(splitTime)
export(stopf)
export(strrepeat)
export(suppressAll)
export(symdiff)
export(system3)
export(toRangeStr)
export(vcapply)
export(viapply)
export(vlapply)
export(vnapply)
export(warningf)
export(which.first)
export(which.last)
import(checkmate)
import(data.table)
import(stats)
import(utils)
importFrom(methods,is)
useDynLib(BBmisc,c_getMaxIndex)
useDynLib(BBmisc,c_getMaxIndexOfCols)
useDynLib(BBmisc,c_getMaxIndexOfRows)
