% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pause.R
\name{pause}
\alias{pause}
\title{Pause in interactive mode and continue on <Enter>.}
\usage{
pause()
}
\description{
Pause in interactive mode and continue on <Enter>.
}
