% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/symdiff.R
\name{symdiff}
\alias{symdiff}
\title{Calculates symmetric set difference between two sets}
\usage{
symdiff(x, y)
}
\arguments{
\item{x}{[\code{vector}]\cr
Set 1.}

\item{y}{[\code{vector}]\cr
Set 2.}
}
\value{
[\code{vector}].
}
\description{
Returns elements that are in either set but not in both.
}
