% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getUnixTime.R
\name{getUnixTime}
\alias{getUnixTime}
\title{Current time in seconds}
\usage{
getUnixTime()
}
\value{
[\code{integer(1)}].
}
\description{
Simple wrapper for \code{as.integer(Sys.time())}.
}
